PyXMake Developer Guide: PyXMake.Tools.ErrorHandling.InputError Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.ErrorHandling.InputError Class Reference

Base class for all input errors. More...

Inheritance diagram for PyXMake.Tools.ErrorHandling.InputError:

## Public Member Functions
| __init__ (self, Expression)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
int | Expression = Expression
| Input expression in which the error occurred.

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Base class for all input errors.

    Exception raised for errors in the input.

    Attributes:
    Expression -- Input expression in which the error occurred

Inherited from Error.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.ErrorHandling.InputError.__init__ | ( |  | self,
|  |  | Expression )

    Low-level initialization of input error class.

Reimplemented from PyXMake.Tools.Utility.AbstractBase.

Definition at line 54 of file ErrorHandling.py.

## Member Data Documentation

## ◆ Expression

int PyXMake.Tools.ErrorHandling.InputError.Expression = Expression

Input expression in which the error occurred.

This is the internal error code.

Definition at line 59 of file ErrorHandling.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/ErrorHandling.py